==> pw-iso20022-SRU2022-9.3.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/ProductClassification1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Specifies attributes of a derivative based on Final ISDA Taxonomy v1.0 and Final ISDA Taxonomy v2.0 (https://www.isda.org/2018/02/20/final-isda-taxonomy-v1-0-and-final-isda-taxonomy-v2-0/).
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProductClassification1", propOrder = {
    "asstClss",
    "basePdct",
    "subPdct",
    "subCmmdty",
    "txTp"
})
public class ProductClassification1 {

    @XmlElement(name = "AsstClss", required = true)
    protected String asstClss;
    @XmlElement(name = "BasePdct")
    protected String basePdct;
    @XmlElement(name = "SubPdct")
    protected String subPdct;
    @XmlElement(name = "SubCmmdty")
    protected String subCmmdty;
    @XmlElement(name = "TxTp")
    protected String txTp;

    /**
     * Gets the value of the asstClss property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAsstClss() {
        return asstClss;
    }

    /**
     * Sets the value of the asstClss property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setAsstClss(String value) {
        this.asstClss = value;
        return this;
    }

    /**
     * Gets the value of the basePdct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBasePdct() {
        return basePdct;
    }

    /**
     * Sets the value of the basePdct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setBasePdct(String value) {
        this.basePdct = value;
        return this;
    }

    /**
     * Gets the value of the subPdct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSubPdct() {
        return subPdct;
    }

    /**
     * Sets the value of the subPdct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setSubPdct(String value) {
        this.subPdct = value;
        return this;
    }

    /**
     * Gets the value of the subCmmdty property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSubCmmdty() {
        return subCmmdty;
    }

    /**
     * Sets the value of the subCmmdty property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setSubCmmdty(String value) {
        this.subCmmdty = value;
        return this;
    }

    /**
     * Gets the value of the txTp property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTxTp() {
        return txTp;
    }

    /**
     * Sets the value of the txTp property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setTxTp(String value) {
        this.txTp = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2023-10.1.7-sources.jar: com/prowidesoftware/swift/model/mx/dic/ProductClassification1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Specifies attributes of a derivative based on Final ISDA Taxonomy v1.0 and Final ISDA Taxonomy v2.0 (https://www.isda.org/2018/02/20/final-isda-taxonomy-v1-0-and-final-isda-taxonomy-v2-0/).
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProductClassification1", propOrder = {
    "asstClss",
    "basePdct",
    "subPdct",
    "subCmmdty",
    "txTp"
})
public class ProductClassification1 {

    @XmlElement(name = "AsstClss", required = true)
    protected String asstClss;
    @XmlElement(name = "BasePdct")
    protected String basePdct;
    @XmlElement(name = "SubPdct")
    protected String subPdct;
    @XmlElement(name = "SubCmmdty")
    protected String subCmmdty;
    @XmlElement(name = "TxTp")
    protected String txTp;

    /**
     * Gets the value of the asstClss property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAsstClss() {
        return asstClss;
    }

    /**
     * Sets the value of the asstClss property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setAsstClss(String value) {
        this.asstClss = value;
        return this;
    }

    /**
     * Gets the value of the basePdct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBasePdct() {
        return basePdct;
    }

    /**
     * Sets the value of the basePdct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setBasePdct(String value) {
        this.basePdct = value;
        return this;
    }

    /**
     * Gets the value of the subPdct property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSubPdct() {
        return subPdct;
    }

    /**
     * Sets the value of the subPdct property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setSubPdct(String value) {
        this.subPdct = value;
        return this;
    }

    /**
     * Gets the value of the subCmmdty property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSubCmmdty() {
        return subCmmdty;
    }

    /**
     * Sets the value of the subCmmdty property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setSubCmmdty(String value) {
        this.subCmmdty = value;
        return this;
    }

    /**
     * Gets the value of the txTp property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTxTp() {
        return txTp;
    }

    /**
     * Sets the value of the txTp property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public ProductClassification1 setTxTp(String value) {
        this.txTp = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
